==> dokuwiki-2013.12.08.tgz: dokuwiki/lib/plugins/acl/lang/he/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author DoK <kamberd@yahoo.com>
 * @author Dotan Kamber <kamberd@yahoo.com>
 * @author Moshe Kaplan <mokplan@gmail.com>
 * @author Yaron Yogev <yaronyogev@gmail.com>
 * @author Yaron Shahrabani <sh.yaron@gmail.com>
 */
$lang['admin_acl']             = 'ניהול רשימת בקרת גישות';
$lang['acl_group']             = 'קבוצה';
$lang['acl_user']              = 'משתמש';
$lang['acl_perms']             = 'הרשאות עבור';
$lang['page']                  = 'דף';
$lang['namespace']             = 'מרחב שמות';
$lang['p_user_id']             = 'למשתמש <b class="acluser">%s</b> יש כרגע את ההרשאות הבאות בדף <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'למשתמש <b class="acluser">%s</b> יש כרגע את ההרשאות הבאות במרחב השם <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'לחברי קבוצת <b class="aclgroup">%s</b> יש כרגע את ההרשאות הבאות בדף <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'לחברי קבוצת <b class="aclgroup">%s</b> יש כרגע את ההרשאות הבאות במרחב השם <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'נא <b>להזין משתמש או קבוצה</b> בטופס מעלה כדי לצפות או לערוך את ההרשאות המוגדרות עבור הדף <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'נא <b>להזין משתמש או קבוצה</b> בטופס מעלה כדי לצפות או לערוך את ההרשאות המוגדרות עבור מרחב השם <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'לתשומת לבך: הרשאות אלו לא הוגדרו באופן מפורש אלא נורשו מקבוצות אחרות או ממרחב שמות גבוה יותר.';
$lang['p_isadmin']             = 'לתשומת לבך: לקבוצה או המשתמש שנבחרו יש תמיד הרשאות מלאות בגלל הגדרתם כמשתמש-על.';
$lang['current']               = 'חוקי ה-ACL הנוכחיים';
$lang['where']                 = 'דף/מרחב שם';
$lang['who']                   = 'משתמש/קבוצה';
$lang['perm']                  = 'הרשאות';
$lang['acl_perm0']             = 'ללא';
$lang['acl_perm1']             = 'קריאה';
$lang['acl_perm2']             = 'עריכה';
$lang['acl_perm4']             = 'יצירה';
$lang['acl_perm8']             = 'העלאה';
$lang['acl_perm16']            = 'מחיקה';
$lang['acl_new']               = 'הוספת רשומה חדשה';
$lang['acl_mod']               = 'שינויי מובאה';

==> dokuwiki-2015.08.10a.tgz: dokuwiki/lib/plugins/acl/lang/he/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author DoK <kamberd@yahoo.com>
 * @author Dotan Kamber <kamberd@yahoo.com>
 * @author Moshe Kaplan <mokplan@gmail.com>
 * @author Yaron Yogev <yaronyogev@gmail.com>
 * @author Yaron Shahrabani <sh.yaron@gmail.com>
 */
$lang['admin_acl']             = 'ניהול רשימת בקרת גישות';
$lang['acl_group']             = 'קבוצה:';
$lang['acl_user']              = 'משתמש:';
$lang['acl_perms']             = 'הרשאות עבור';
$lang['page']                  = 'דף';
$lang['namespace']             = 'מרחב שמות';
$lang['p_user_id']             = 'למשתמש <b class="acluser">%s</b> יש כרגע את ההרשאות הבאות בדף <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'למשתמש <b class="acluser">%s</b> יש כרגע את ההרשאות הבאות במרחב השם <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'לחברי קבוצת <b class="aclgroup">%s</b> יש כרגע את ההרשאות הבאות בדף <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'לחברי קבוצת <b class="aclgroup">%s</b> יש כרגע את ההרשאות הבאות במרחב השם <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'נא <b>להזין משתמש או קבוצה</b> בטופס מעלה כדי לצפות או לערוך את ההרשאות המוגדרות עבור הדף <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'נא <b>להזין משתמש או קבוצה</b> בטופס מעלה כדי לצפות או לערוך את ההרשאות המוגדרות עבור מרחב השם <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'לתשומת לבך: הרשאות אלו לא הוגדרו באופן מפורש אלא נורשו מקבוצות אחרות או ממרחב שמות גבוה יותר.';
$lang['p_isadmin']             = 'לתשומת לבך: לקבוצה או המשתמש שנבחרו יש תמיד הרשאות מלאות בגלל הגדרתם כמשתמש-על.';
$lang['current']               = 'חוקי ה-ACL הנוכחיים';
$lang['where']                 = 'דף/מרחב שם';
$lang['who']                   = 'משתמש/קבוצה';
$lang['perm']                  = 'הרשאות';
$lang['acl_perm0']             = 'ללא';
$lang['acl_perm1']             = 'קריאה';
$lang['acl_perm2']             = 'עריכה';
$lang['acl_perm4']             = 'יצירה';
$lang['acl_perm8']             = 'העלאה';
$lang['acl_perm16']            = 'מחיקה';
$lang['acl_new']               = 'הוספת רשומה חדשה';
$lang['acl_mod']               = 'שינויי מובאה';
